( cd usr/lib ; rm -rf libGL.so.1 )
( cd usr/lib ; ln -sf libGL.so.1.5.070900 libGL.so.1 )
( cd usr/lib ; rm -rf libGLU.so.1 )
( cd usr/lib ; ln -sf libGLU.so.1.3.070900 libGLU.so.1 )
( cd usr/lib ; rm -rf libglut.so.3 )
( cd usr/lib ; ln -sf libglut.so.3.7.1 libglut.so.3 )
( cd usr/lib ; rm -rf libGLw.so )
( cd usr/lib ; ln -sf libGLw.so.1 libGLw.so )
( cd usr/lib ; rm -rf libGL.so )
( cd usr/lib ; ln -sf libGL.so.1 libGL.so )
( cd usr/lib ; rm -rf libglut.so )
( cd usr/lib ; ln -sf libglut.so.3 libglut.so )
( cd usr/lib ; rm -rf libEGL.so )
( cd usr/lib ; ln -sf libEGL.so.1 libEGL.so )
( cd usr/lib ; rm -rf libGLw.so.1 )
( cd usr/lib ; ln -sf libGLw.so.1.0.0 libGLw.so.1 )
( cd usr/lib ; rm -rf libEGL.so.1 )
( cd usr/lib ; ln -sf libEGL.so.1.0 libEGL.so.1 )
( cd usr/lib ; rm -rf libGLU.so )
( cd usr/lib ; ln -sf libGLU.so.1 libGLU.so )
